@@ -17,6 +17,13 @@ def get_sg(sg_name: str, profile: str):
     target_sg_str = list(filter(lambda x: x['GroupName']==sg_name, resp['SecurityGroups']))
     return target_sg_str
 
+def check_if_aux(ip_permissions: list):
+    try:
+        return 'Aux' in ip_permissions['IpRanges'][0]['Description']
+    except IndexError as e:
+        assert ip_permissions['IpRanges']==[]
+        return False
+
 def update_sg_to_ip(sg_name='jakub', # ip='2.222.105.71/32',
                     ports=[22, 8501, 8888], profile='default'):
     import boto3
@@ -30,8 +37,10 @@ def update_sg_to_ip(sg_name='jakub', # ip='2.222.105.71/32',
     ec2_res = boto3.session.Session(profile_name=profile, region_name='eu-west-1').resource('ec2')
     sg_res = ec2_res.SecurityGroup(target_sg_str['GroupId'])
 
-    # loop using ports to only remove SSH/Jupyter and not e.g. NFS
-    permissions_to_revoke = [ s for s in sg_res.ip_permissions if s['FromPort'] in ports ]
+    # loop using description to only remove Aux and not e.g. NFS or Home
+    # old port-based solution
+    # permissions_to_revoke = [ s for s in sg_res.ip_permissions if s['FromPort'] in ports ]
+    permissions_to_revoke = [ s for s in sg_res.ip_permissions if check_if_aux(s) ]
 
     # Removes all relevant permissions from this group (originally as `jakub`)
     if sg_res.ip_permissions!=[]:
