@@ -12,6 +12,8 @@ def execute(command: str, filt_cond: str, directory=''):
     '''
     df = get_files_as_pd(directory)
 
+    import ipdb; ipdb.set_trace()
+
     target_files = pd.Series(filter(lambda x: filt_cond in x, df.full_path.values))
     target_fcn = lambda x: os.system(eval(command))
     target_files.swifter.apply(lambda x: target_fcn(x))
@@ -19,12 +21,14 @@ def execute(command: str, filt_cond: str, directory=''):
 
 def get_files_as_pd(directory):
     '''
+    directory: `str` of full_path
+
     Gets all files from recursive directories and returns this as
     a `DataFrame`
     '''
     # TODO: find a way to print STDOUT and STDERR as a print statement
     try:
-        proc = str(sp.check_output(f'find $PWD/{directory}* -type f',
+        proc = str(sp.check_output(f'find {directory}* -type f',
                                     shell=True,stderr=sp.PIPE))[2:]
     except sp.CalledProcessError as e:
         print(f'Error {e} Possibly incorrect path.')
@@ -35,3 +39,4 @@ def get_files_as_pd(directory):
     level_paths = df.full_path.str.split('/',expand=True)
     df = pd.concat([df, level_paths], axis=1)
     return df
+
